aboutsummaryrefslogtreecommitdiffstats
path: root/mod
diff options
context:
space:
mode:
authorredmatrix <redmatrix@redmatrix.me>2015-05-14 18:02:29 -0700
committerredmatrix <redmatrix@redmatrix.me>2015-05-14 18:02:29 -0700
commita6cb90c81c29663e96d4fd96acd43fde1c28ac15 (patch)
tree24d116fb5fe6b1e2687f833cee9685d6480a95eb /mod
parentb467dc4f0055452b65fac842d1294ec9cc978445 (diff)
parent51b89f0ed8833004cf695de90791d8d0eec550b5 (diff)
downloadvolse-hubzilla-a6cb90c81c29663e96d4fd96acd43fde1c28ac15.tar.gz
volse-hubzilla-a6cb90c81c29663e96d4fd96acd43fde1c28ac15.tar.bz2
volse-hubzilla-a6cb90c81c29663e96d4fd96acd43fde1c28ac15.zip
Merge branch 'master' into tres
Conflicts: include/Import/refimport.php include/activities.php include/attach.php include/event.php include/externals.php include/identity.php include/items.php include/notifier.php include/photos.php include/taxonomy.php include/zot.php mod/channel.php mod/connedit.php mod/events.php mod/item.php mod/like.php mod/manage.php mod/mood.php mod/ping.php mod/poke.php mod/subthread.php mod/tagger.php mod/thing.php
Diffstat (limited to 'mod')
-rw-r--r--mod/admin.php4
-rw-r--r--mod/cloud.php8
-rw-r--r--mod/dav.php8
-rw-r--r--mod/editlayout.php2
-rwxr-xr-xmod/events.php2
-rw-r--r--mod/help.php2
-rw-r--r--mod/home.php4
-rw-r--r--mod/invite.php6
-rw-r--r--mod/item.php29
-rw-r--r--mod/layouts.php2
-rwxr-xr-xmod/like.php4
-rw-r--r--mod/mitem.php21
-rw-r--r--mod/p.php2
-rw-r--r--mod/page.php7
-rw-r--r--mod/parse_url.php2
-rw-r--r--mod/ping.php2
-rwxr-xr-xmod/poke.php1
-rw-r--r--mod/probe.php3
-rw-r--r--mod/pubsites.php2
-rwxr-xr-xmod/setup.php4
-rw-r--r--mod/siteinfo.php12
-rw-r--r--mod/tagger.php2
-rw-r--r--mod/webpages.php5
-rw-r--r--mod/zfinger.php2
24 files changed, 67 insertions, 69 deletions
diff --git a/mod/admin.php b/mod/admin.php
index 7d0497a7b..c8a227c74 100644
--- a/mod/admin.php
+++ b/mod/admin.php
@@ -1,7 +1,7 @@
<?php
/**
* @file mod/admin.php
- * @brief RedMatrix's admin controller.
+ * @brief Hubzilla's admin controller.
*
* Controller for the /admin/ area.
*/
@@ -232,7 +232,7 @@ function admin_page_summary(&$a) {
$alertmsg = '';
// annoy admin about upcoming unsupported PHP version
if (version_compare(PHP_VERSION, '5.4', '<')) {
- $alertmsg = 'Your PHP version ' . PHP_VERSION . ' will not be supported with the next major release of RedMatrix. You are strongly urged to upgrade to a current version.'
+ $alertmsg = 'Your PHP version ' . PHP_VERSION . ' will not be supported with the next major release of Hubzilla. You are strongly urged to upgrade to a current version.'
. '<br>PHP 5.3 has reached its <a href="http://php.net/eol.php" class="alert-link">End of Life (EOL)</a> in August 2014.'
. ' A list about current PHP versions can be found <a href="http://php.net/supported-versions.php" class="alert-link">here</a>.';
}
diff --git a/mod/editlayout.php b/mod/editlayout.php
index a3879a381..d61a14a48 100644
--- a/mod/editlayout.php
+++ b/mod/editlayout.php
@@ -130,7 +130,7 @@ function editlayout_content(&$a) {
// FIXME A return path with $_SESSION doesn't always work for observer - it may WSoD
// instead of loading a sensible page. So, send folk to the webpage list.
- $rp = '/layouts/' . $which;
+ $rp = 'layouts/' . $which;
$o .= replace_macros($tpl,array(
'$return_path' => $rp,
diff --git a/mod/events.php b/mod/events.php
index 077095fbe..a89bbb760 100755
--- a/mod/events.php
+++ b/mod/events.php
@@ -414,7 +414,7 @@ function events_content(&$a) {
$is_first = ($d !== $last_date);
$last_date = $d;
-// FIXME
+
$edit = (intval($rr['item_wall']) ? array($a->get_baseurl().'/events/event/'.$rr['event_hash'],t('Edit event'),'','') : null);
$drop = array($a->get_baseurl().'/events/drop/'.$rr['event_hash'],t('Delete event'),'','');
diff --git a/mod/help.php b/mod/help.php
index 0081e54e7..3d7c0a628 100644
--- a/mod/help.php
+++ b/mod/help.php
@@ -97,7 +97,7 @@ function help_content(&$a) {
$content = preg_replace_callback("/#include (.*?)\;/ism", 'preg_callback_help_include', $content);
return replace_macros(get_markup_template("help.tpl"), array(
- '$content' => $content
+ '$content' => translate_projectname($content)
));
}
diff --git a/mod/home.php b/mod/home.php
index 3cbaf097c..68ffc1807 100644
--- a/mod/home.php
+++ b/mod/home.php
@@ -50,7 +50,7 @@ function home_content(&$a, $update = 0, $load = false) {
if(get_config('system','projecthome')) {
$o .= file_get_contents('assets/home.html');
$a->page['template'] = 'full';
- $a->page['title'] = t('Red Matrix - &quot;The Network&quot;');
+ $a->page['title'] = t('Hubzilla - &quot;The Network&quot;');
return $o;
}
@@ -190,7 +190,7 @@ function home_content(&$a, $update = 0, $load = false) {
if(get_config('system','site_firehose')) {
require_once('include/security.php');
- $uids = " and item.uid in ( " . stream_perms_api_uids(PERMS_PUBLIC) . " ) and item_private = 0 and (item_flags & " . intval(ITEM_WALL) . " ) > 0 ";
+ $uids = " and item.uid in ( " . stream_perms_api_uids(PERMS_PUBLIC) . " ) and item_private = 0 and item_wall = 1 ";
}
else {
$sys = get_sys_channel();
diff --git a/mod/invite.php b/mod/invite.php
index e197278d1..81e10bcd8 100644
--- a/mod/invite.php
+++ b/mod/invite.php
@@ -129,12 +129,12 @@ function invite_content(&$a) {
'$invite' => t('Send invitations'),
'$addr_text' => t('Enter email addresses, one per line:'),
'$msg_text' => t('Your message:'),
- '$default_message' => t('Please join my community on RedMatrix.') . "\r\n" . "\r\n"
+ '$default_message' => t('Please join my community on Hubzilla.') . "\r\n" . "\r\n"
. $linktxt
. (($invonly) ? "\r\n" . "\r\n" . t('You will need to supply this invitation code: ') . $invite_code . "\r\n" . "\r\n" : '')
- . t('1. Register at any RedMatrix location (they are all inter-connected)')
+ . t('1. Register at any Hubzilla location (they are all inter-connected)')
. "\r\n" . "\r\n" . z_root() . '/register'
- . "\r\n" . "\r\n" . t('2. Enter my RedMatrix network address into the site searchbar.')
+ . "\r\n" . "\r\n" . t('2. Enter my Hubzilla network address into the site searchbar.')
. "\r\n" . "\r\n" . $ob['xchan_addr'] . ' (' . t('or visit ') . z_root() . '/channel/' . $channel['channel_address'] . ')'
. "\r\n" . "\r\n"
. t('3. Click [Connect]')
diff --git a/mod/item.php b/mod/item.php
index ecb54e604..36cbaff6c 100644
--- a/mod/item.php
+++ b/mod/item.php
@@ -652,6 +652,7 @@ function item_post(&$a) {
}
}
+
$item_unseen = ((local_channel() != $profile_uid) ? 1 : 0);
$item_wall = (($post_type === 'wall' || $post_type === 'wall-comment') ? 1 : 0);
$item_origin = (($origin) ? 1 : 0);
@@ -687,14 +688,8 @@ function item_post(&$a) {
$item_thead_top = ((! $parent) ? 1 : 0);
-<<<<<<< HEAD
- if ((! $plink) && ($item_thread_top)) {
-=======
- if($consensus)
- $item_flags |= ITEM_CONSENSUS;
- if ((! $plink) && ($item_flags & ITEM_THREAD_TOP)) {
->>>>>>> master
+ if ((! $plink) && ($item_thread_top)) {
$plink = z_root() . '/channel/' . $channel['channel_address'] . '/?f=&mid=' . $mid;
}
@@ -724,6 +719,7 @@ function item_post(&$a) {
$datarray['deny_cid'] = $str_contact_deny;
$datarray['deny_gid'] = $str_group_deny;
$datarray['item_private'] = $private;
+ $datarray['item_wall'] = $item_wall;
$datarray['attach'] = $attachments;
$datarray['thr_parent'] = $thr_parent;
$datarray['postopts'] = $postopts;
@@ -787,14 +783,6 @@ function item_post(&$a) {
$datarray['item_verified'] = 1;
}
}
-
- logger('Encrypting local storage');
- $key = get_config('system','pubkey');
- $datarray['item_obscured'] = 1;
- if($datarray['title'])
- $datarray['title'] = json_encode(crypto_encapsulate($datarray['title'],$key));
- if($datarray['body'])
- $datarray['body'] = json_encode(crypto_encapsulate($datarray['body'],$key));
}
if($orig_post) {
@@ -1080,24 +1068,15 @@ function item_check_service_class($channel_id,$iswebpage) {
$ret = array('success' => false, $message => '');
if ($iswebpage) {
-<<<<<<< HEAD
$r = q("select count(i.id) as total from item i
right join channel c on (i.author_xchan=c.channel_hash and i.uid=c.channel_id )
and i.parent=i.id and i.item_type = %d and i.item_deleted = 0 and i.uid= %d ",
intval(ITEM_TYPE_WEBPAGE),
-=======
- // note: we aren't counting comanche templates and blocks, only webpages
- $r = q("select count(id) as total from item where parent = id
- and ( item_restrict & %d ) > 0 and ( item_restrict & %d ) = 0 and uid = %d ",
- intval(ITEM_WEBPAGE),
- intval(ITEM_DELETED),
->>>>>>> master
intval($channel_id)
);
}
else {
- $r = q("select count(id) as total from item where parent = id and item_restrict = 0 and (item_flags & %d) > 0 and uid = %d ",
- intval(ITEM_WALL),
+ $r = q("select count(id) as total from item where parent = id and item_restrict = 0 and item_wall = 1 and uid = %d ",
intval($channel_id)
);
}
diff --git a/mod/layouts.php b/mod/layouts.php
index b42debe18..9d27ed4ac 100644
--- a/mod/layouts.php
+++ b/mod/layouts.php
@@ -99,7 +99,7 @@ function layouts_content(&$a) {
dbesc(argv(3))
);
if($r) {
- header('Content-type: application/x-redmatrix-layout');
+ header('Content-type: application/x-hubzilla-layout');
header('Content-disposition: attachment; filename="' . $r[0]['sid'] . '.pdl"');
echo json_encode($r);
killme();
diff --git a/mod/like.php b/mod/like.php
index 35c72bb12..22960562f 100755
--- a/mod/like.php
+++ b/mod/like.php
@@ -18,7 +18,7 @@ function like_content(&$a) {
if(! $observer) {
$_SESSION['return_url'] = $a->query_string;
$o .= t('This action is restricted to members.') . EOL;
- $o .= t('Please <a href="rmagic">login with your RedMatrix ID</a> or <a href="register">register as a new RedMatrix member</a> to continue.') . EOL;
+ $o .= t('Please <a href="rmagic">login with your Hubzilla ID</a> or <a href="register">register as a new Redmatrix.member</a> to continue.') . EOL;
return $o;
}
}
@@ -338,6 +338,7 @@ function like_content(&$a) {
}
$mid = item_message_id();
+
$arr = array();
if($extended_like) {
@@ -440,6 +441,7 @@ function like_content(&$a) {
$arr['aid'] = (($extended_like) ? $ch[0]['channel_account_id'] : $owner_aid);
$arr['uid'] = $owner_uid;
$arr['item_flags'] = $item_flags;
+ $arr['item_wall'] = $item_wall;
$arr['parent_mid'] = (($extended_like) ? $mid : $item['mid']);
$arr['owner_xchan'] = (($extended_like) ? $ch[0]['xchan_hash'] : $thread_owner['xchan_hash']);
$arr['author_xchan'] = $observer['xchan_hash'];
diff --git a/mod/mitem.php b/mod/mitem.php
index 06c66a323..9a80ba88b 100644
--- a/mod/mitem.php
+++ b/mod/mitem.php
@@ -124,6 +124,13 @@ function mitem_content(&$a) {
$m = menu_fetch($a->data['menu']['menu_name'],$uid,$ob_hash);
$a->data['menu_item'] = $m;
+ $menu_list = menu_list($uid);
+
+ foreach($menu_list as $menus) {
+ if($menus['menu_name'] != $m['menu']['menu_name'])
+ $menu_names[] = $menus['menu_name'];
+ }
+
$perm_defaults = array(
'allow_cid' => $channel['channel_allow_cid'],
'allow_gid' => $channel['channel_allow_gid'],
@@ -152,14 +159,15 @@ function mitem_content(&$a) {
'$permdesc' => t("\x28click to open/close\x29"),
'$aclselect' => populate_acl($perm_defaults,false),
'$mitem_desc' => array('mitem_desc', t('Link Name'), '', 'Visible name of the link','*'),
- '$mitem_link' => array('mitem_link', t('Link Target'), '', 'URL of the link', '*'),
- '$usezid' => array('usezid', t('Use RedMatrix magic-auth if available'), true, ''),
+ '$mitem_link' => array('mitem_link', t('Link or Submenu Target'), '', 'Enter URL of the link or select a menu name to create a submenu', '*', 'list="menu-names"'),
+ '$usezid' => array('usezid', t('Use magic-auth if available'), true, ''),
'$newwin' => array('newwin', t('Open link in new window'), false,''),
'$mitem_order' => array('mitem_order', t('Order in list'),'0',t('Higher numbers will sink to bottom of listing')),
'$submit' => t('Submit and finish'),
'$submit_more' => t('Submit and continue'),
'$display' => $display,
- '$lockstate' => $lockstate
+ '$lockstate' => $lockstate,
+ '$menu_names' => $menu_names
));
$o .= replace_macros(get_markup_template('mitemlist.tpl'),array(
@@ -222,12 +230,13 @@ function mitem_content(&$a) {
'$aclselect' => populate_acl($mitem,false),
'$mitem_id' => intval(argv(2)),
'$mitem_desc' => array('mitem_desc', t('Link text'), $mitem['mitem_desc'], '','*'),
- '$mitem_link' => array('mitem_link', t('URL of link'), $mitem['mitem_link'], '', '*'),
- '$usezid' => array('usezid', t('Use RedMatrix magic-auth if available'), (($mitem['mitem_flags'] & MENU_ITEM_ZID) ? 1 : 0), ''),
+ '$mitem_link' => array('mitem_link', t('Link or Submenu Target'), $mitem['mitem_link'], t('Enter URL of the link or select a menu name to create a submenu'), '*', 'list="menu-name"'),
+ '$usezid' => array('usezid', t('Use Hubzilla magic-auth if available'), (($mitem['mitem_flags'] & MENU_ITEM_ZID) ? 1 : 0), ''),
'$newwin' => array('newwin', t('Open link in new window'), (($mitem['mitem_flags'] & MENU_ITEM_NEWWIN) ? 1 : 0),''),
'$mitem_order' => array('mitem_order', t('Order in list'),$mitem['mitem_order'],t('Higher numbers will sink to bottom of listing')),
'$submit' => t('Submit'),
- '$lockstate' => $lockstate
+ '$lockstate' => $lockstate,
+ '$menu_names' => $menu_names
));
return $o;
diff --git a/mod/p.php b/mod/p.php
index 80e835a91..f467ae5a5 100644
--- a/mod/p.php
+++ b/mod/p.php
@@ -42,7 +42,7 @@ function p_init(&$a) {
'$handle' => xmlify($myaddr),
'$public' => 'true',
'$created' => $created,
- '$provider' => (($item['app']) ? $item['app'] : 'redmatrix')
+ '$provider' => (($item['app']) ? $item['app'] : 'hubzilla')
));
header('Content-type: text/xml');
diff --git a/mod/page.php b/mod/page.php
index eedfd472c..2d977fb7a 100644
--- a/mod/page.php
+++ b/mod/page.php
@@ -35,7 +35,11 @@ function page_init(&$a) {
}
$channel_address = argv(1);
- $page_id = argv(2);
+
+ // The page link title was stored in a urlencoded format
+ // php or the browser may/will have decoded it, so re-encode it for our search
+
+ $page_id = urlencode(argv(2));
$u = q("select channel_id from channel where channel_address = '%s' limit 1",
dbesc($channel_address)
@@ -62,7 +66,6 @@ function page_init(&$a) {
intval(ITEM_TYPE_WEBPAGE),
intval(ITEM_PDL)
);
-
if(! $r) {
// Check again with no permissions clause to see if it is a permissions issue
diff --git a/mod/parse_url.php b/mod/parse_url.php
index b6c0559f9..2a6f7663e 100644
--- a/mod/parse_url.php
+++ b/mod/parse_url.php
@@ -325,7 +325,7 @@ function parse_url_content(&$a) {
// If this is a Red site, use zrl rather than url so they get zids sent to them by default
- if( x($siteinfo,'generator') && (strpos($siteinfo['generator'],RED_PLATFORM . ' ') === 0))
+ if( x($siteinfo,'generator') && (strpos($siteinfo['generator'],PLATFORM_NAME . ' ') === 0))
$template = str_replace('url','zrl',$template);
if($siteinfo["title"] == "") {
diff --git a/mod/ping.php b/mod/ping.php
index f84bc498d..d43694358 100644
--- a/mod/ping.php
+++ b/mod/ping.php
@@ -157,7 +157,7 @@ function ping_init(&$a) {
break;
case 'home':
$r = q("update item set item_unseen = 0 where item_unseen = 1 and item_wall = 1 and uid = %d",
- intval(channel())
+ intval(local_channel())
);
break;
case 'messages':
diff --git a/mod/poke.php b/mod/poke.php
index d0f60e853..f66d28956 100755
--- a/mod/poke.php
+++ b/mod/poke.php
@@ -88,6 +88,7 @@ function poke_init(&$a) {
$arr = array();
+ $arr['item_wall'] = 1;
$arr['owner_xchan'] = (($parent_item) ? $parent_item['owner_xchan'] : $channel['channel_hash']);
$arr['parent_mid'] = (($parent_mid) ? $parent_mid : $mid);
$arr['title'] = '';
diff --git a/mod/probe.php b/mod/probe.php
index 8e0b60dcc..62a2227b0 100644
--- a/mod/probe.php
+++ b/mod/probe.php
@@ -15,6 +15,7 @@ function probe_content(&$a) {
if(x($_GET,'addr')) {
$channel = $a->get_channel();
$addr = trim($_GET['addr']);
+ $do_import = ((intval($_GET['import']) && is_site_admin()) ? true : false);
$res = zot_finger($addr,$channel,false);
$o .= '<pre>';
if($res['success'])
@@ -29,6 +30,8 @@ function probe_content(&$a) {
$o .= sprintf( t('Fetching URL returns error: %1$s'),$res['error'] . "\r\n\r\n");
}
+ if($do_import && $j)
+ $x = import_xchan($j);
if($j && $j['permissions'] && $j['permissions']['iv'])
$j['permissions'] = json_decode(crypto_unencapsulate($j['permissions'],$channel['channel_prvkey']),true);
$o .= str_replace("\n",'<br />',print_r($j,true));
diff --git a/mod/pubsites.php b/mod/pubsites.php
index ff3854492..ccddff2d8 100644
--- a/mod/pubsites.php
+++ b/mod/pubsites.php
@@ -16,7 +16,7 @@ function pubsites_content(&$a) {
$o .= '<h1>' . t('Public Sites') . '</h1>';
$o .= '<div class="descriptive-text">' .
- t('The listed sites allow public registration into the Red Matrix. All sites in the matrix are interlinked so membership on any of them conveys membership in the matrix as a whole. Some sites may require subscription or provide tiered service plans. The provider links <strong>may</strong> provide additional details.') . '</div>' . EOL;
+ t('The listed sites allow public registration into the Hubzilla. All sites in the matrix are interlinked so membership on any of them conveys membership in the matrix as a whole. Some sites may require subscription or provide tiered service plans. The provider links <strong>may</strong> provide additional details.') . '</div>' . EOL;
$ret = z_fetch_url($url);
if($ret['success']) {
diff --git a/mod/setup.php b/mod/setup.php
index b885388be..0a560e6df 100755
--- a/mod/setup.php
+++ b/mod/setup.php
@@ -163,7 +163,7 @@ function setup_content(&$a) {
global $install_wizard_pass, $db;
$o = '';
$wizard_status = "";
- $install_title = t('Red Matrix Server - Setup');
+ $install_title = t('Hubzilla Server - Setup');
@@ -287,7 +287,7 @@ function setup_content(&$a) {
$o .= replace_macros($tpl, array(
'$title' => $install_title,
'$pass' => t('Database connection'),
- '$info_01' => t('In order to install Red Matrix we need to know how to connect to your database.'),
+ '$info_01' => t('In order to install Hubzilla we need to know how to connect to your database.'),
'$info_02' => t('Please contact your hosting provider or site administrator if you have questions about these settings.'),
'$info_03' => t('The database you specify below should already exist. If it does not, please create it before continuing.'),
diff --git a/mod/siteinfo.php b/mod/siteinfo.php
index 856909a27..d9464f4f6 100644
--- a/mod/siteinfo.php
+++ b/mod/siteinfo.php
@@ -90,7 +90,7 @@ function siteinfo_init(&$a) {
'default_service_restrictions' => $service_class,
'admin' => $admin,
'site_name' => (($site_name) ? $site_name : ''),
- 'platform' => RED_PLATFORM,
+ 'platform' => PLATFORM_NAME,
'dbdriver' => $db->getdriver(),
'lastpoll' => get_config('system','lastpoll'),
'info' => (($site_info) ? $site_info : ''),
@@ -153,7 +153,7 @@ function siteinfo_content(&$a) {
$o = replace_macros(get_markup_template('siteinfo.tpl'), array(
'$title' => t('Red'),
- '$description' => t('This is a hub of redmatrix - a global cooperative network of decentralized privacy enhanced websites.'),
+ '$description' => t('This is a hub of hubzilla - a global cooperative network of decentralized privacy enhanced websites.'),
'$version' => $version,
'$tag_txt' => t('Tag: '),
'$tag' => $tag,
@@ -161,11 +161,11 @@ function siteinfo_content(&$a) {
'$lastpoll' => get_poller_runtime(),
'$commit' => $commit,
'$web_location' => t('Running at web location') . ' ' . z_root(),
- '$visit' => t('Please visit <a href="https://redmatrix.me">redmatrix.me</a> to learn more about the Red Matrix.'),
+ '$visit' => t('Please visit <a href="https://redmatrix.me">redmatrix.me</a> to learn more about the Hubzilla.'),
'$bug_text' => t('Bug reports and issues: please visit'),
- '$bug_link_url' => 'https://github.com/redmatrix/redmatrix/issues',
- '$bug_link_text' => 'redmatrix issues',
- '$contact' => t('Suggestions, praise, etc. - please email "redmatrix" at librelist - dot com'),
+ '$bug_link_url' => 'https://github.com/redmatrix/hubzilla/issues',
+ '$bug_link_text' => 'hubzilla issues',
+ '$contact' => t('Suggestions, praise, etc. - please email "hubzilla" at librelist - dot com'),
'$donate' => $donate,
'$adminlabel' => t('Site Administrators'),
'$admininfo' => $admininfo,
diff --git a/mod/tagger.php b/mod/tagger.php
index 5c2c3c909..c6365d707 100644
--- a/mod/tagger.php
+++ b/mod/tagger.php
@@ -109,7 +109,7 @@ function tagger_content(&$a) {
$arr['item_origin'] = 1;
$arr['item_wall'] = ((intval($item['item_wall'])) ? 1 : 0);
-
+
$ulink = '[zrl=' . $channel['xchan_url'] . ']' . $channel['channel_name'] . '[/zrl]';
$alink = '[zrl=' . $item['xchan_url'] . ']' . $item['xchan_name'] . '[/zrl]';
$plink = '[zrl=' . $item['plink'] . ']' . $post_type . '[/zrl]';
diff --git a/mod/webpages.php b/mod/webpages.php
index e04cbdc11..f7043d5e1 100644
--- a/mod/webpages.php
+++ b/mod/webpages.php
@@ -133,8 +133,9 @@ function webpages_content(&$a) {
$sql_extra = item_permissions_sql($owner);
$r = q("select * from item_id left join item on item_id.iid = item.id
- where item_id.uid = %d and service = 'WEBPAGE' $sql_extra order by item.created desc",
- intval($owner)
+ where item_id.uid = %d and service = 'WEBPAGE' and item_restrict = %d $sql_extra order by item.created desc",
+ intval($owner),
+ intval(ITEM_WEBPAGE)
);
$pages = null;
diff --git a/mod/zfinger.php b/mod/zfinger.php
index 2f544d10e..37243922c 100644
--- a/mod/zfinger.php
+++ b/mod/zfinger.php
@@ -280,7 +280,7 @@ function zfinger_init(&$a) {
$ret['site']['channels'] = channel_total();
- $ret['site']['version'] = RED_PLATFORM . ' ' . RED_VERSION . '[' . DB_UPDATE_VERSION . ']';
+ $ret['site']['version'] = PLATFORM_NAME . ' ' . RED_VERSION . '[' . DB_UPDATE_VERSION . ']';
$ret['site']['admin'] = get_config('system','admin_email');
diff --git a/mod/cloud.php b/mod/cloud.php
index b36e6c482..a87d36ea1 100644
--- a/mod/cloud.php
+++ b/mod/cloud.php
@@ -1,13 +1,13 @@
<?php
/**
* @file mod/cloud.php
- * @brief Initialize RedMatrix's cloud (SabreDAV).
+ * @brief Initialize Hubzilla's cloud (SabreDAV).
*
* Module for accessing the DAV storage area.
*/
use Sabre\DAV;
-use RedMatrix\RedDAV;
+use Hubzilla\RedDAV;
// composer autoloader for SabreDAV
require_once('vendor/autoload.php');
@@ -117,7 +117,7 @@ function cloud_init(&$a) {
if ((! $auth->observer) && (! $isapublic_file) && (! $davguest)) {
try {
- $auth->Authenticate($server, t('RedMatrix - Guests: Username: {your email address}, Password: +++'));
+ $auth->Authenticate($server, t('Hubzilla - Guests: Username: {your email address}, Password: +++'));
}
catch (Exception $e) {
logger('mod_cloud: auth exception' . $e->getMessage());
@@ -126,7 +126,7 @@ function cloud_init(&$a) {
}
require_once('include/RedDAV/RedBrowser.php');
// provide a directory view for the cloud in Red Matrix
$browser = new RedDAV\RedBrowser($auth);
$auth->setBrowserPlugin($browser);
@@ -126,7 +126,7 @@ function cloud_init(&$a) {
}
require_once('include/RedDAV/RedBrowser.php');
- // provide a directory view for the cloud in Red Matrix
+ // provide a directory view for the cloud in Hubzilla
$browser = new RedDAV\RedBrowser($auth);
$auth->setBrowserPlugin($browser);
diff --git a/mod/dav.php b/mod/dav.php
index f7f89b6da..d49dd7359 100644
--- a/mod/dav.php
+++ b/mod/dav.php
@@ -1,13 +1,13 @@
<?php
/**
* @file mod/dav.php
- * @brief Initialize RedMatrix's cloud (SabreDAV).
+ * @brief Initialize Hubzilla's cloud (SabreDAV).
*
* Module for accessing the DAV storage area from a DAV client.
*/
use Sabre\DAV;
-use RedMatrix\RedDAV;
+use Hubzilla\RedDAV;
// composer autoloader for SabreDAV
require_once('vendor/autoload.php');
@@ -118,7 +118,7 @@ function dav_init(&$a) {
if ((! $auth->observer) && (! $isapublic_file) && (! $davguest)) {
try {
- $auth->Authenticate($server, t('RedMatrix channel'));
+ $auth->Authenticate($server, t('Hubzilla channel'));
}
catch (Exception $e) {
logger('mod_cloud: auth exception' . $e->getMessage());
@@ -127,7 +127,7 @@ function dav_init(&$a) {
}
require_once('include/RedDAV/RedBrowser.php');
// provide a directory view for the cloud in Red Matrix
$browser = new RedDAV\RedBrowser($auth);
$auth->setBrowserPlugin($browser);
@@ -127,7 +127,7 @@ function dav_init(&$a) {
}
require_once('include/RedDAV/RedBrowser.php');
- // provide a directory view for the cloud in Red Matrix
+ // provide a directory view for the cloud in Hubzilla
$browser = new RedDAV\RedBrowser($auth);
$auth->setBrowserPlugin($browser);